@@ -20,13 +20,14 @@ class Datomizer(object):
             Datomizer Authentication object"""
         self.domain = authentication_helper.get_domain_by_username(username=username, env=env)
         self.realm = authentication_helper.get_realm_by_domain(domain=self.domain)
-        token_response = authentication_helper.get_token(username=username, password=password,
-                                                         domain=self.domain, realm=self.realm)
+        token_response = authentication_helper.post_token(realm=self.realm, domain=self.domain,
+                                                          username=username, password=password)
         self.config_token(token_response)
 
     def refresh_token_headers(self):
-        token_response = authentication_helper.refresh_token(domain=self.domain, realm=self.realm,
-                                                             token=self.refresh_token)
+        token_response = authentication_helper.post_refresh_token(realm=self.realm,
+                                                                  domain=self.domain,
+                                                                  token=self.refresh_token)
         self.config_token(token_response)
 
     def config_token(self, token_response):
@@ -73,3 +74,7 @@ class Datomizer(object):
             print(response.url)
             print(response.content)
             raise Exception(not_valid_message)
+
+    def __del__(self):
+        authentication_helper.post_log_out(realm=self.realm, domain=self.domain,
+                                           token=self.access_token, refresh_token=self.refresh_token)
